import { getEndpointPlugin } from "@smithy/middleware-endpoint";
import { getSerdePlugin } from "@smithy/middleware-serde";
import { Command as $Command } from "@smithy/smithy-client";
import { SMITHY_CONTEXT_KEY, } from "@smithy/types";
import { StartEdgeConfigurationUpdateInputFilterSensitiveLog, StartEdgeConfigurationUpdateOutputFilterSensitiveLog, } from "../models/models_0";
import { de_StartEdgeConfigurationUpdateCommand, se_StartEdgeConfigurationUpdateCommand, } from "../protocols/Aws_restJson1";
export { $Command };
export class StartEdgeConfigurationUpdateCommand extends $Command {
    static getEndpointParameterInstructions() {
        return {
            UseFIPS: { type: "builtInParams", name: "useFipsEndpoint" },
            Endpoint: { type: "builtInParams", name: "endpoint" },
            Region: { type: "builtInParams", name: "region" },
            UseDualStack: { type: "builtInParams", name: "useDualstackEndpoint" },
        };
    }
    constructor(input) {
        super();
        this.input = input;
    }
    resolveMiddleware(clientStack, configuration, options) {
        this.middlewareStack.use(getSerdePlugin(configuration, this.serialize, this.deserialize));
        this.middlewareStack.use(getEndpointPlugin(configuration, StartEdgeConfigurationUpdateCommand.getEndpointParameterInstructions()));
        const stack = clientStack.concat(this.middlewareStack);
        const { logger } = configuration;
        const clientName = "KinesisVideoClient";
        const commandName = "StartEdgeConfigurationUpdateCommand";
        const handlerExecutionContext = {
            logger,
            clientName,
            commandName,
            inputFilterSensitiveLog: StartEdgeConfigurationUpdateInputFilterSensitiveLog,
            outputFilterSensitiveLog: StartEdgeConfigurationUpdateOutputFilterSensitiveLog,
            [SMITHY_CONTEXT_KEY]: {
                service: "KinesisVideo_20170930",
                operation: "StartEdgeConfigurationUpdate",
            },
        };
        const { requestHandler } = configuration;
        return stack.resolve((request) => requestHandler.handle(request.request, options || {}), handlerExecutionContext);
    }
    serialize(input, context) {
        return se_StartEdgeConfigurationUpdateCommand(input, context);
    }
    deserialize(output, context) {
        return de_StartEdgeConfigurationUpdateCommand(output, context);
    }
}
