import { EndpointParameterInstructions } from "@smithy/middleware-endpoint";
import { Command as $Command } from "@smithy/smithy-client";
import { Handler, HttpHandlerOptions as __HttpHandlerOptions, MetadataBearer as __MetadataBearer, MiddlewareStack } from "@smithy/types";
import { KinesisVideoClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../KinesisVideoClient";
import { ListSignalingChannelsInput, ListSignalingChannelsOutput } from "../models/models_0";
/**
 * @public
 */
export { __MetadataBearer, $Command };
/**
 * @public
 *
 * The input for {@link ListSignalingChannelsCommand}.
 */
export interface ListSignalingChannelsCommandInput extends ListSignalingChannelsInput {
}
/**
 * @public
 *
 * The output of {@link ListSignalingChannelsCommand}.
 */
export interface ListSignalingChannelsCommandOutput extends ListSignalingChannelsOutput, __MetadataBearer {
}
/**
 * @public
 * <p>Returns an array of <code>ChannelInfo</code> objects. Each object describes a
 *             signaling channel. To retrieve only those channels that satisfy a specific condition,
 *             you can specify a <code>ChannelNameCondition</code>.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { KinesisVideoClient, ListSignalingChannelsCommand } from "@aws-sdk/client-kinesis-video"; // ES Modules import
 * // const { KinesisVideoClient, ListSignalingChannelsCommand } = require("@aws-sdk/client-kinesis-video"); // CommonJS import
 * const client = new KinesisVideoClient(config);
 * const input = { // ListSignalingChannelsInput
 *   MaxResults: Number("int"),
 *   NextToken: "STRING_VALUE",
 *   ChannelNameCondition: { // ChannelNameCondition
 *     ComparisonOperator: "BEGINS_WITH",
 *     ComparisonValue: "STRING_VALUE",
 *   },
 * };
 * const command = new ListSignalingChannelsCommand(input);
 * const response = await client.send(command);
 * // { // ListSignalingChannelsOutput
 * //   ChannelInfoList: [ // ChannelInfoList
 * //     { // ChannelInfo
 * //       ChannelName: "STRING_VALUE",
 * //       ChannelARN: "STRING_VALUE",
 * //       ChannelType: "SINGLE_MASTER" || "FULL_MESH",
 * //       ChannelStatus: "CREATING" || "ACTIVE" || "UPDATING" || "DELETING",
 * //       CreationTime: new Date("TIMESTAMP"),
 * //       SingleMasterConfiguration: { // SingleMasterConfiguration
 * //         MessageTtlSeconds: Number("int"),
 * //       },
 * //       Version: "STRING_VALUE",
 * //     },
 * //   ],
 * //   NextToken: "STRING_VALUE",
 * // };
 *
 * ```
 *
 * @param ListSignalingChannelsCommandInput - {@link ListSignalingChannelsCommandInput}
 * @returns {@link ListSignalingChannelsCommandOutput}
 * @see {@link ListSignalingChannelsCommandInput} for command's `input` shape.
 * @see {@link ListSignalingChannelsCommandOutput} for command's `response` shape.
 * @see {@link KinesisVideoClientResolvedConfig | config} for KinesisVideoClient's `config` shape.
 *
 * @throws {@link AccessDeniedException} (client fault)
 *  <p>You do not have required permissions to perform this operation.</p>
 *
 * @throws {@link ClientLimitExceededException} (client fault)
 *  <p>Kinesis Video Streams has throttled the request because you have exceeded the limit of
 *             allowed client calls. Try making the call later.</p>
 *
 * @throws {@link InvalidArgumentException} (client fault)
 *  <p>The value for this input parameter is invalid.</p>
 *
 * @throws {@link KinesisVideoServiceException}
 * <p>Base exception class for all service exceptions from KinesisVideo service.</p>
 *
 */
export declare class ListSignalingChannelsCommand extends $Command<ListSignalingChannelsCommandInput, ListSignalingChannelsCommandOutput, KinesisVideoClientResolvedConfig> {
    readonly input: ListSignalingChannelsCommandInput;
    static getEndpointParameterInstructions(): EndpointParameterInstructions;
    /**
     * @public
     */
    constructor(input: ListSignalingChannelsCommandInput);
    /**
     * @internal
     */
    resolveMiddleware(clientStack: MiddlewareStack<ServiceInputTypes, ServiceOutputTypes>, configuration: KinesisVideoClientResolvedConfig, options?: __HttpHandlerOptions): Handler<ListSignalingChannelsCommandInput, ListSignalingChannelsCommandOutput>;
    /**
     * @internal
     */
    private serialize;
    /**
     * @internal
     */
    private deserialize;
}
